Rio — Dashboard

## Live Transcript

0
Live Translation Counterparty
Staff
Bidirectional Translator off

Waiting for conversation...

## Struggle Detection

0.00
No signals
Repeated Error
Long Pause
Rapid Changes
Stale + Active

## Tool Execution

0

No tool executions yet

## Schedules

0
No active schedule session.

## System Health

RPM Usage
0 / 30
Session Time
00:00
Messages
0
Screenshots
0
Triggers
0
Rate Status
Normal